# Trauts

## Installation
```
pip install trauts
```

## Usage

### Using CLI
```
trauts --input-csv=tests/data/test_points.csv
```

### Using Docker
```
docker build -t trauts .
```

```
docker run trauts --input-csv=tests/data/test_points.csv
```
